@@ -2,10 +2,10 @@ from typing    import List, Optional, Tuple
 from xml.etree import ElementTree as et
 from .struct   import Lookup
 
-def _xml(s: str) -> List[et.Element]:
+def _xml(s: bytes) -> List[et.Element]:
     return list(et.fromstring(s.strip()))
 
-def add(data: str) -> Tuple[Optional[int], str]:
+def add(data: bytes) -> Tuple[Optional[int], str]:
     responses = _xml(data)
     id: Optional[int] = None
     if responses[0].tag == "success":
@@ -14,15 +14,12 @@ def add(data: str) -> Tuple[Optional[int], str]:
         id, responses[0].get("data", "")
     )
 
-def lookup(data: str) -> Optional[Lookup]:
+def lookup(data: bytes) -> List[Lookup]:
     responses = _xml(data)
-    if (not responses or
-            not responses[0].tag == "result"):
-        return None
-    else:
-        response = responses[0]
-        port     = response.get("port", "")
-        return Lookup(
+    lookups: List[Lookup] = []
+    for response in responses:
+        port   = response.get("port", "")
+        lookup = Lookup(
             response.get("ip", ""),
             int(response.get("id", "")),
             int(response.get("type", "")),
@@ -30,8 +27,10 @@ def lookup(data: str) -> Optional[Lookup]:
             None if port == "" else int(port),
             int(response.get("timestamp", ""))
         )
+        lookups.append(lookup)
+    return lookups
 
-def remove(data: str) -> Tuple[bool, str]:
+def remove(data: bytes) -> Tuple[bool, str]:
     responses = _xml(data)
     return (
         responses[0].tag == "success",
